/**
 * Container Generator
 */

const componentExists = require('../utils/componentExists');

module.exports = {
  description: 'Add a container component',
  prompts    : [
    {
      type    : 'input',
      name    : 'name',
      message : 'What should it be called?',
      default : 'Form',
      validate: value => {
        if ((/.+/).test(value)) {
          return componentExists(value) ? 'A component or container with this name already exists' : true;
        }

        return 'The name is required';
      }
    },
    {
      type   : 'confirm',
      name   : 'wantCSS',
      default: false,
      message: 'Does it have styling?'
    }
  ],
  actions    : data => {
    // Generate index.js and index.test.js
    const actions = [ {
      type        : 'add',
      path        : '../../src/components/{{properCase name}}/{{properCase name}}.js',
      templateFile: './container/index.js.hbs',
      abortOnFail : true
    }, {
      type        : 'add',
      path        : '../../src/components/{{properCase name}}/package.json',
      templateFile: './container/package.json.hbs',
      abortOnFail : true
    } ];

    // If they want a CSS file, add styles.css
    if (data.wantCSS) {
      actions.push({
        type        : 'add',
        path        : '../../src/components/{{properCase name}}/{{properCase name}}.scss',
        templateFile: './container/styles.scss.hbs',
        abortOnFail : true
      });
    }

    return actions;
  }
};
