import React, { Component, PropTypes } from 'react';
import classNames from 'classnames';

import './CircularImage.scss';

class CircularImage extends Component {

  static propTypes = {
    src      : PropTypes.string.isRequired,
    size     : PropTypes.number.isRequired,
    hoverZoom: PropTypes.bool
  };

  componentWillMount() {
    this.loadImage();
  }

  componentDidUpdate(prevProps, prevState) {
    if (prevProps.src != this.props.src)
      this.loadImage();
  }


  loadImage() {
    this.setState({
      imageStyle: {}
    });

    const image = new Image();

    image.onload = () => {
      this.setState({
        imageSrc  : this.props.src,
        imageStyle: image.width > image.height
          ? { height: '100%', width: 'auto', maxWidth: 'inherit' }
          : { width: '100%', height: 'auto', maxHeight: 'inherit' }
      });
    };

    image.src = this.props.src;
  }


  render() {
    const className = classNames(
      'CircularImage',
      this.props.className,
      { hoverZoom: this.props.hoverZoom }
    );

    const style = {
      width     : this.props.size,
      height    : this.props.size,
      background: !this.state.imageSrc && 'rgba(0,0,0,.3)'
    };

    return (
      <div className={className} style={style}>
        <img
          src={this.state.imageSrc}
          alt={this.state.imageSrc && this.props.alt}
          style={this.state.imageStyle}
        />
      </div>
    );
  }
}

export default CircularImage;