import React, { Component, PropTypes } from 'react';

import './ContextMenu.scss';

class ContextMenu extends Component {

  static propTypes = {
    options  : PropTypes.array,
    enabled  : PropTypes.bool,
    leftClick: PropTypes.bool,
    align    : PropTypes.oneOf([ 'left', 'right' ])
  };

  static defaultProps = {
    options  : [],
    enabled  : true,
    leftClick: false,
    align    : 'right'
  };

  constructor(props) {
    super(props);

    this.state = {
      shouldShowMenu: false,
      menuX         : 0,
      menuY         : 0
    };

    this.handleOpenIntent = this.handleOpenIntent.bind(this);
  }

  handleOpenIntent(e) {
    if (!this.props.enabled) return;

    e.preventDefault();

    var shouldShowMenu = !this.state.shouldShowMenu;

    this.setState({
      shouldShowMenu: shouldShowMenu,
      menuX         : e.pageX + 2,
      menuY         : e.pageY + 2
    });

    if (shouldShowMenu) {
      var closeListener = (e) => {
        var elem = e.target;

        while (elem.parentNode != null) {
          if (elem == this.refs.root) return;
          elem = elem.parentNode;
        }

        window.removeEventListener('click', closeListener);
        window.removeEventListener('contextmenu', closeListener);

        this.setState({ shouldShowMenu: false });
      };

      setTimeout(() => {
        window.addEventListener('click', closeListener);
        window.addEventListener('contextmenu', closeListener);
      });
    }
  }

  render() {
    const menuStyle = { [this.props.align]: 0 };

    return (
      <div
        className="ContextMenu"
        onContextMenu={this.handleOpenIntent}
        onClick={(e) => this.props.leftClick && this.handleOpenIntent(e)}
      >
        {this.props.children}
        {
          this.state.shouldShowMenu &&
          <ul className="menu" style={menuStyle}>
            {
              this.props.options.map(opt => {
                return <li key={opt.label} className="item" onClick={opt.action}>{opt.label}</li>
              })
            }
          </ul>
        }
      </div>
    );
  }
}


export default ContextMenu;
