import React, { PropTypes } from 'react';
import { OverlayView } from 'react-google-maps';

function DriverMarker({ position, color, size, mapHolderRef }) {
  const colorFill = { fill: color };

  const rootProps = {
    mapPaneName           : OverlayView.MARKER_LAYER,
    position              : position,
    mapHolderRef          : mapHolderRef,
    getPixelPositionOffset: () => ({ x: -size / 2, y: -size })
  };

  const svgStyle = {
    width : size,
    height: size
  };

  //@formatter:off
  return (
    <OverlayView {...rootProps}>
      <svg viewBox="0 0 212.38 256" style={svgStyle}>
        <defs>
          <linearGradient id="linear-gradient" x1="128" y1="256" x2="128" y2="186.48" gradientUnits="userSpaceOnUse">
            <stop offset="0" stopOpacity="0"/>
            <stop offset="0.84" stopOpacity="0.48"/>
            <stop offset="0.85" stopOpacity="0.5"/>
          </linearGradient>
        </defs>
        <path style={colorFill} d="M234.19,106.19a105.93,105.93,0,0,1-25.87,69.49L128,256,47.68,175.68a106.2,106.2,0,1,1,186.51-69.49Z" transform="translate(-21.81)" />
        <path style={colorFill} d="M47.68,175.68l10.8,10.8A115.32,115.32,0,0,1,47.68,175.68Z" transform="translate(-21.81)"/>
        <path style={colorFill} d="M208.32,175.68a115.32,115.32,0,0,1-10.8,10.8Z" transform="translate(-21.81)" />
        <path style={{ fill: 'url(#linear-gradient)' }} d="M197.52,186.48,128,256,58.48,186.48a106.26,106.26,0,0,0,139,0Z" transform="translate(-21.81)"/>
        <g>
          <polygon style={{ fill: '#ffffff' }} points="33.44 89.16 61.61 126.93 115.75 116.77 33.44 89.16"/>
          <polygon style={{ fill: '#ffffff' }} points="178.94 110.64 155.25 114.86 155.25 114.86 64.86 131 158.19 131 178.94 110.64"/>
          <polygon style={{ fill: '#ffffff' }} points="154.21 109.55 106.22 68.59 72.84 97.18 125.5 114.94 154.14 109.56 154.21 109.55"/>
        </g>
      </svg>
    </OverlayView>
  );
  //@formatter:on
}

DriverMarker.propTypes = {
  position: PropTypes.shape({
    lat: PropTypes.number,
    lng: PropTypes.number,
  }),
  color   : PropTypes.string,
  size    : PropTypes.number
};

DriverMarker.defaultProps = {
  color: '#666',
  size : 24
};

export default DriverMarker;