import React, { Component, PropTypes } from 'react';

import Animated     from '../Animated';
import neutralSound from 'file!./audio/neutral.ogg';
import failureSound from 'file!./audio/failure.ogg';

import './Notifier.scss';

const sounds = {
  neutral: null,
  failure: null
};

class Notifier extends Component {
  static messages = [];

  static propTypes = {
    neutralSound: PropTypes.string,
    failureSound: PropTypes.string,
    autoHide    : PropTypes.bool
  };

  static defaultProps = {
    neutralSound: `/${neutralSound}`,
    failureSound: `/${failureSound}`
  };

  static pushMessage(item) {
    item.id = Date.now();

    Notifier.messages.push(item);

    window.dispatchEvent(new Event('__notifier_update'));

    item.type == 'error'
      ? sounds.failure.play()
      : sounds.neutral.play();

    const calculatedTimeToHide = 3000 + item.message.split(' ').length * 500;
    const timeToHide           = item.timeout || calculatedTimeToHide;

    if (timeToHide > 0)
      setTimeout(() => Notifier.removeMessage(item), timeToHide);
  }

  static removeMessage(item) {
    Notifier.messages = Notifier.messages.filter(it => it != item);
    window.dispatchEvent(new Event('__notifier_update'));
  }

  static error(message, timeout = 0) {
    Notifier.pushMessage({ message, timeout, type: 'error' });
  }

  static info(message, timeout = 0) {
    Notifier.pushMessage({ message, timeout, type: 'info' });
  }

  static success(message, timeout = 0) {
    Notifier.pushMessage({ message, timeout, type: 'success' });
  }

  static repeatSounds() {
    const shouldPlaySound = { neutral: false, failure: false };

    Notifier.messages.forEach(it => {
      (it.type == 'error')
        ? shouldPlaySound.failure = true
        : shouldPlaySound.neutral = true;
    });

    const soundsToPlay = [];

    shouldPlaySound.neutral && soundsToPlay.push(sounds.neutral);
    shouldPlaySound.failure && soundsToPlay.push(sounds.failure);

    (function playSounds() {
      if (!soundsToPlay.length) return;
      soundsToPlay.pop().play();
      setTimeout(playSounds, 1000);
    })();
  }

  constructor(props) {
    super(props);

    window.addEventListener('__notifier_update', () => this.forceUpdate());

    sounds.neutral = new Audio(props.neutralSound);
    sounds.failure = new Audio(props.failureSound);

    sounds.neutral.volume = .3;
    sounds.failure.volume = .3;

    setInterval(() => Notifier.repeatSounds(), 2000);
  }

  render() {
    return (
      <div className="Notifier">
        <Animated>
          {
            Notifier.messages.map(it => {
              return (
                <div
                  className={it.type}
                  key={it.id}
                  onClick={() => Notifier.removeMessage(it)}
                >
                  <div className="type">{it.type}</div>
                  {it.message}
                </div>
              );
            })
          }
        </Animated>
      </div>
    );
  }
}

export default Notifier;