import React, { Component, PropTypes } from 'react';
import { TextField } from 'armduishrdcmpnts';
import './Prompt.scss';

class Prompt extends Component {

  static propTypes = {
    onDiscard       : PropTypes.func,
    onConfirm       : PropTypes.func.isRequired,
    inputLabel      : PropTypes.string.isRequired,
    discardLabel    : PropTypes.string,
    confirmLabel    : PropTypes.string,
    confirmClassName: PropTypes.string,
    placeholder     : PropTypes.string
  };

  static defaultProps = {
    discardLabel: 'Cancel',
    confirmLabel: 'Ok'
  };

  constructor(props) {
    super(props);

    this.state = { input: '' };

    this.handleSubmit      = this.handleSubmit.bind(this);
    this.handleInputChange = this.handleInputChange.bind(this);
    this.handleDiscard     = this.handleDiscard.bind(this);
  }

  show() {
    this.setState({ show: true }, () => {
      this.refs.box.querySelector('input').focus();
    });
  }

  isShowing() {
    return this.state.show;
  }

  handleSubmit(e) {
    e.preventDefault();
    this.props.onConfirm(this.state.input);
    this.setState({ show: false });
  }

  handleInputChange(e) {
    this.setState({ input: e.nativeEvent.target.value });
  }

  handleDiscard() {
    this.props.onDiscard && this.props.onDiscard();
    this.setState({ show: false });
  }

  render() {
    var props = this.props;

    return (
      <div className={`Prompt fade-in ${this.state.show && 'show'}` }>
        <form className="box" ref="box" onSubmit={this.handleSubmit}>
          {props.children}
          <TextField
            label={props.inputLabel}
            className="input"
            placeholder={props.placeholder}
            value={this.state.input}
            onChange={this.handleInputChange}
          />
          <div className="actionButtons">
            <button className="button" type="button" onClick={this.handleDiscard}>{props.discardLabel}</button>
            <button
              className={`button ${props.confirmClassName || 'primary'}` }
              type="submit"
            >
              {props.confirmLabel}
            </button>
          </div>
        </form>
      </div>
    );
  }
}

export default Prompt;
