import React, { Component, PropTypes } from 'react';
import MaskedInput    from 'react-maskedinput';
import Label          from '../Label';
import ErrorMessage   from '../ErrorMessage';
import classNames     from 'classnames';

import './TextField.scss';

class TextField extends Component {

  static propTypes = {
    currency     : PropTypes.bool,
    decimalPlaces: PropTypes.number,
    type         : PropTypes.string,
    onChange     : PropTypes.func,
    autoComplete : PropTypes.string,
    prefix       : PropTypes.string,
    suffix       : PropTypes.string,
    rows         : PropTypes.number,
    value        : PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.number
    ]).isRequired,
  };

  static defaultProps = {
    value       : '',
    rows        : 1,
    type        : 'text',
    autoComplete: 'off',
    onChange    : new Function()
  };

  render() {
    let { label, mask, error, currency, decimalPlaces, className, rows, ...props } = this.props;

    if (currency) {
      props.onFocus = (e) => {
        const target = e.nativeEvent.target;
        target.value = target.value || '';
      };

      props.onChange = (e) => {
        const target       = e.nativeEvent.target;
        const prevOnChange = this.props.onChange;
        let clearValue     = target.value.replace(/\D/, '');
        decimalPlaces      = decimalPlaces || 2;

        target.selectionStart = target.selectionEnd = target.value.length;

        clearValue = clearValue
          ? parseInt(clearValue, 10) / Math.pow(10, decimalPlaces)
          : 0;

        prevOnChange && prevOnChange(clearValue.toFixed(decimalPlaces));
      };
    }

    className = classNames('TextField', className, { currency, error });

    return (
      <div className={className}>
        <Label content={label}/>
        {
          mask
            ? <MaskedInput mask={mask} {...props}/>
            : rows == 1 ? <input {...props} /> : <textarea rows={rows} {...props}/>
        }
        <ErrorMessage error={error}/>
      </div>
    );
  }
}

export default TextField;
