import React, { Component, PropTypes } from 'react';
import classNames   from 'classnames';
import Label        from '../Label';
import ErrorMessage from '../ErrorMessage';

import './ToggleGroup.scss';

class ToggleGroup extends Component {
  static propTypes = {
    options: PropTypes.array
  };

  constructor(props) {
    super(props);

    this.state        = { error: props.error || '' };
    this.selectOption = this.selectOption.bind(this);
  }

  componentDidUpdate(prevProps, prevState) {
    if (this.props.error != prevProps.error)
      setTimeout(() => this.setState({error: this.props.error}), 50);
  }

  selectOption(option) {
    if (this.props.value == option.value)
      option = null;

    this.props.onChange && this.props.onChange(option.value);

    setTimeout(() => {
      this.props.onFocus && this.props.onFocus();
      this.props.onBlur && this.props.onBlur();
    }, 0);
  }

  renderButtons() {
    return this.props.options.map(opt => {
        var optClassName = classNames({ selected: opt.value == this.props.value });

        return (
          <button
            key={`${opt.value};${opt.label}`}
            type="button"
            className={optClassName}
            onClick={() => this.selectOption(opt)}
          >
            {opt.label}
          </button>
        );
      }
    );
  }

  render() {
    return (
      <div className="ToggleGroup">
        <Label content={this.props.label}/>
        <div className="buttonsContainer">
          {this.renderButtons()}
        </div>
        <ErrorMessage error={this.state.error}/>
      </div>
    );
  }
}

export default ToggleGroup;
