import React, { Component, PropTypes } from 'react';
import ReactDOM from 'react-dom';

import AddressBox     from './components/AddressBox';
import Autocomplete   from './components/Autocomplete';
import FormSection    from './components/FormSection';
import TextField      from './components/TextField';
import ToggleGroup    from './components/ToggleGroup';
import CircularImage  from './components/CircularImage';
import FileInput      from './components/FileInput';
import ContextMenu    from './components/ContextMenu';
import Notifier       from './components/Notifier';
import Button         from './components/Button';
import DialogBox      from './components/DialogBox';
import formy          from 'react-formy';
import validate       from 'validate.js';

import './demo.scss';

class Demo extends Component {
  static validateForm(values) {
    return validate(values, {
      'user.name': { presence: true },
      'value'    : { numericality: { greaterThan: 2 } }
    });
  }

  constructor(props) {
    super(props);

    this.state = {
      showDialog: true
    };
  }

  onSubmit(values) {
    console.log(values);
  }

  render() {
    const field          = this.props.field;
    const arrayField     = this.props.arrayField;
    const form           = this.props.form;
    const handleSubmit   = this.props.handleSubmit;
    const handleAddClick = () => arrayField('items').push({ name: 'john' });

    var items         = form.items || [];
    var toggleOptions = [
      { value: '1', label: 'One' },
      { value: '2', label: 'Two' }
    ];

    var transformation = JSON.stringify({
      width  : 250,
      height : 250,
      crop   : 'thumb',
      gravity: 'face',
      // effect : 'fill_light'
    });

    var uploadUrl = `http://localhost:3030/upload?transformation=${transformation}`;

    return (
      <div className="Demo">
        Armada UI Demo

        <Notifier />
        <div className="pure-g">
          <div className="pure-u-2-3">
            <form onSubmit={handleSubmit(this.onSubmit)}>
              <FormSection title="Lorem ipsum dolor">

                <TextField
                  label="Name"
                  {...field('user.name')}
                />

                <TextField
                  label="Bio"
                  rows={5}
                  {...field('user.bio')}
                />

                <TextField
                  label="Birthday"
                  mask="11/11/1111"
                  {...field('birthday')}
                />

                <AddressBox
                  label="Address"
                  showMap
                  {...field('address')}
                />

                <ToggleGroup
                  label="Toggle"
                  options={toggleOptions}
                  {...field('toggle')}
                />

                <div className="pure-g">
                  <div className="pure-u-1-2">
                    <Autocomplete
                      label="Dropdown"
                      options={[
                        { value: '1', label: 'Lorem' },
                        { value: '2', label: 'Ipsum' }
                      ]}
                    />
                  </div>
                  <div className="pure-u-1-2">
                    <TextField
                      label="Value"
                      currency={true}
                      decimalPlaces={3}
                      {...field('value')}
                    />
                  </div>
                </div>


                <div className="pure-g">
                  <div className="pure-u-1-2">
                    <FileInput
                      label="Contract"
                      camera={true}
                      types="application/pdf,image/*"
                      uploadUrl={uploadUrl}
                      {...field('photo')}
                    />
                  </div>
                  <div className="pure-u-1-2">
                    <Autocomplete
                      label="Dropdown"
                      showOptionsOnFocus={true}
                      options={[
                        { value: '1', label: 'Lorem' },
                        { value: '2', label: 'Ipsum' }
                      ]}
                      {...field('dropdown')}
                      error="teste"
                    />
                  </div>
                </div>

                <div>
                  <ContextMenu
                    leftClick
                    align="left"
                    options={[
                      { label: 'Lorem ipsum', action: () => console.log('lorem ipsum') },
                      { label: 'Dolor sit', action: () => console.log('dolor sit') }
                    ]}
                  >
                    <button type="button">Lorem Ipsum</button>
                  </ContextMenu>
                </div>


                <br/>
                <br/>

                <CircularImage src={field('photo').value || ''} hoverZoom size={50}/>
                <CircularImage src="http://goo.gl/ZLzo5H" hoverZoom size={50}/>

                <br/>
                <br/>

                {items.map((it, i) => <TextField key={i} {...field('items[].name', i)}/>)}

                <Button
                  label="Add"
                  type="button"
                  onClick={handleAddClick}
                />
                <Button
                  type="button"
                  onClick={() => Notifier.success('Teste lorem ipsum dolor sit amet', -1)}
                  label="Notify success"
                />

                <Button
                  type="button"
                  onClick={() => Notifier.error('Teste lorem ipsum dolor sit amet', -1)}
                  label="Notify failure"
                />

                <Button
                  type="button"
                  onClick={() => this.setState({showDialog: true})}
                  label="Open dialog"
                />

                <DialogBox
                  isVisible={this.state.showDialog}
                  onClickOut={() => this.setState({showDialog: false})}
                >
                  <div style={{width: '3000px', height: '400px'}}>Lorem ipsum dolor sit amet</div>
                </DialogBox>

              </FormSection>

              <br/>
              <br/>

              <button type="submit">Save info</button>
            </form>
          </div>
        </div>
      </div>
    );
  }
}

const ConnectedDemo = formy(Demo);

ReactDOM.render(<ConnectedDemo/>, document.querySelector('#main'));
